@@ -3,7 +3,7 @@ package Cache::RedisDB;
 use 5.010;
 use strict;
 use warnings FATAL => 'all';
-use Carp;
+
 use RedisDB 2.14;
 use Sereal qw(looks_like_sereal);
 
@@ -13,20 +13,15 @@ Cache::RedisDB - RedisDB based cache system
 
 =head1 VERSION
 
-Version 0.08
+Version 0.01
 
 =head1 DESCRIPTION
 
 This is just a warpper around RedisDB to have a single Redis object and connection per process. By default uses server 127.0.0.1:6379, but it may be overwritten by REDIS_CACHE_SERVER environment variable. It transparently handles forks.
 
-=head1 COMPATIBILITY AND REQUIREMENTS
-
-Redis 2.6.12 and higher strongly recommended.  Required if you want to use
-extended options in ->set().
-
 =cut
 
-our $VERSION = '0.080_4';
+our $VERSION = '0.01';
 
 =head1 SYNOPSIS
 
@@ -36,7 +31,7 @@ our $VERSION = '0.080_4';
 
 =head1 SUBROUTINES/METHODS
 
-=head2 redis_server_info
+=head2 redis_server_info 
 
 Returns redis host and port separated by colon
 
@@ -58,9 +53,7 @@ sub redis_connection {
         host               => $server,
         port               => $port,
         reconnect_attempts => 3,
-        on_connect_error   => sub {
-            confess "Cannot connect to server $server:$port";
-        });
+    );
 }
 
 =head2 redis
@@ -83,7 +76,7 @@ Retrieve I<$key> value from the cache.
 
 sub get {
     my ($self, $namespace, $key) = @_;
-    my $res = redis->get(_cache_key($namespace, $key));
+    my $res = redis->get("${namespace}::${key}");
     if (looks_like_sereal($res)) {
         state $decoder = Sereal::Decoder->new();
         $res = $decoder->decode($res);
@@ -101,19 +94,15 @@ If I<$exptime> specified, it is expiration time in seconds.
 sub set {
     my ($self, $namespace, $key, $value, $exptime, $callback) = @_;
     if (not defined $value or ref $value or Encode::is_utf8($value)) {
-        state $encoder = Sereal::Encoder->new({
-            freeze_callbacks => 1,
-            protocol_version => 2
-        });
+        state $encoder = Sereal::Encoder->new({freeze_callbacks => 1});
         $value = $encoder->encode($value);
     }
-    my $cache_key = _cache_key($namespace, $key);
     if (defined $exptime) {
         $exptime = int(1000 * $exptime);
         # PX milliseconds -- Set the specified expire time, in milliseconds
-        return redis->set($cache_key, $value, "PX", $exptime, $callback // ());
+        return redis->set("${namespace}::${key}", $value, "PX", $exptime, $callback // ());
     } else {
-        return redis->set($cache_key, $value, $callback // ());
+        return redis->set("${namespace}::${key}", $value, $callback // ());
     }
 }
 
@@ -138,43 +127,7 @@ Returns number of deleted keys.
 
 sub del {
     my ($self, $namespace, @keys) = @_;
-    return redis->del(map { _cache_key($namespace, $_) } @keys);
-}
-
-=head2 keys($namespace)
-
-Return a list of all known keys in the provided I<$namespace>.
-
-=cut
-
-sub keys {
-    my ($self, $namespace) = @_;
-    my $prefix = _cache_key($namespace, undef);
-    return [map { s/^$prefix//; $_ } @{redis->keys($prefix . '*')}];
-}
-
-=head2 ttl($namespace, $key)
-
-Return the Time To Live (in seconds) of a key in the provided I<$namespace>.
-
-=cut
-
-sub ttl {
-    my ($self, $namespace, $key) = @_;
-
-    my $ms = redis->pttl(_cache_key($namespace, $key));
-    # We pessimistically round to the start of the second where it
-    # will disappear.  While slightly wrong, it is likely less confusing.
-    # Nonexistent (or already expired) keys should return 0;
-    return ($ms <= 0) ? 0 : int($ms / 1000);
-}
-
-sub _cache_key {
-    my ($namespace, $key) = @_;
-    $namespace //= '';
-    $key       //= '';
-
-    return $namespace . '::' . $key;
+    return redis->del(map { "${namespace}::$_" } @keys);
 }
 
 =head3 flushall
@@ -229,6 +182,10 @@ L<http://search.cpan.org/dist/Cache-RedisDB/>
 
 =back
 
+
+=head1 ACKNOWLEDGEMENTS
+
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2014 binary.com.
@@ -272,4 +229,4 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
 
-1;    # End of Cache::RedisDB
+1; # End of Cache::RedisDB
